/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */

package com.yifu.cloud.plus.v1.yifu.salary.entity;

import com.alibaba.excel.annotation.ExcelProperty;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.yifu.cloud.plus.v1.yifu.common.core.constant.ExcelAttribute;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import org.hibernate.validator.constraints.Length;

import javax.validation.constraints.NotBlank;
import java.math.BigDecimal;

/**
 * 工资报账表附加-工资明细
 *
 * @author hgw
 * @date 2022-08-05 11:40:15
 */
@Data
@TableName("t_salary_account_item")
@Schema(description = "工资报账表附加-工资明细")
public class TSalaryAccountItem {

	/**
	 * 主键
	 */
	@TableId(type = IdType.ASSIGN_ID)
	@ExcelProperty("主键")
	private String id;
	/**
	 * 工资报账表ID
	 */
	@ExcelAttribute(name = "工资报账表ID", isNotEmpty = true, errorInfo = "工资报账表ID不能为空", maxLength = 32)
	@NotBlank(message = "工资报账表ID不能为空")
	@Length(max = 32, message = "工资报账表ID不能超过32个字符")
	@ExcelProperty("工资报账表ID")
	private String salaryAccountId;
	/**
	 * 表头名称
	 */
	@ExcelAttribute(name = "表头名称", isNotEmpty = true, errorInfo = "表头名称不能为空", maxLength = 50)
	@NotBlank(message = "表头名称不能为空")
	@Length(max = 50, message = "表头名称不能超过50个字符")
	@ExcelProperty("表头名称")
	private String cnName;
	/**
	 * JAVA属性名称
	 */
	@ExcelAttribute(name = "JAVA属性名称", isNotEmpty = true, errorInfo = "JAVA属性名称不能为空", maxLength = 32)
	@NotBlank(message = "JAVA属性名称不能为空")
	@Length(max = 32, message = "JAVA属性名称不能超过32个字符")
	@ExcelProperty("JAVA属性名称")
	private String javaFiedName;
	/**
	 * 属性值
	 */
	@ExcelAttribute(name = "属性值")
	@ExcelProperty("属性值")
	private BigDecimal salaryMoney;
	/**
	 * 是否进行计算扣税：1：计算；0：不计算
	 */
	@ExcelAttribute(name = "是否进行计算扣税：1：计算；0：不计算", isNotEmpty = true, errorInfo = "是否进行计算扣税：1：计算；0：不计算不能为空")
	@NotBlank(message = "是否进行计算扣税：1：计算；0：不计算不能为空")
	@ExcelProperty("是否进行计算扣税：1：计算；0：不计算")
	private Integer isTax;
	/**
	 * 文本值
	 */
	@ExcelAttribute(name = "文本值", maxLength = 500)
	@Length(max = 500, message = "文本值不能超过500个字符")
	@ExcelProperty("文本值")
	private String textValue;

}
