/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */

package com.yifu.cloud.plus.v1.yifu.salary.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yifu.cloud.plus.v1.yifu.common.core.util.R;
import com.yifu.cloud.plus.v1.yifu.common.log.annotation.SysLog;
import com.yifu.cloud.plus.v1.yifu.salary.entity.TSalaryAtta;
import com.yifu.cloud.plus.v1.yifu.salary.service.TSalaryAttaService;
import com.yifu.cloud.plus.v1.yifu.salary.vo.TSalaryAttaSearchVo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;


/**
 * 薪资结算附件表
 *
 * @author hgw
 * @date 2022-08-05 11:40:14
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/tsalaryatta")
@Tag(name = "薪资结算附件表管理")
public class TSalaryAttaController {

	private final TSalaryAttaService tSalaryAttaService;


	/**
	 * 简单分页查询
	 *
	 * @param page        分页对象
	 * @param tSalaryAtta 薪资结算附件表
	 * @return
	 */
	@Operation(description = "简单分页查询")
	@GetMapping("/page")
	public R<IPage<TSalaryAtta>> getTSalaryAttaPage(Page<TSalaryAtta> page, TSalaryAttaSearchVo tSalaryAtta) {
		return new R<>(tSalaryAttaService.getTSalaryAttaPage(page, tSalaryAtta));
	}

	/**
	 * 不分页查询
	 *
	 * @param tSalaryAtta 薪资结算附件表
	 * @return
	 */
	@Operation(summary = "不分页查询", description = "不分页查询")
	@PostMapping("/noPage")
	//@PreAuthorize("@pms.hasPermission('salary_tsalaryatta_get')" )
	public R<List<TSalaryAtta>> getTSalaryAttaNoPage(@RequestBody TSalaryAttaSearchVo tSalaryAtta) {
		return R.ok(tSalaryAttaService.noPageDiy(tSalaryAtta));
	}

	/**
	 * 通过id查询薪资结算附件表
	 *
	 * @param id id
	 * @return R
	 */
	@Operation(summary = "通过id查询", description = "通过id查询：hasPermission('salary_tsalaryatta_get')")
	@GetMapping("/{id}")
	public R<TSalaryAtta> getById(@PathVariable("id") String id) {
		return R.ok(tSalaryAttaService.getById(id));
	}

	/**
	 * 新增薪资结算附件表
	 *
	 * @param tSalaryAtta 薪资结算附件表
	 * @return R
	 */
	@Operation(summary = "新增薪资结算附件表", description = "新增薪资结算附件表：hasPermission('salary_tsalaryatta_add')")
	@SysLog("新增薪资结算附件表")
	@PostMapping
	@PreAuthorize("@pms.hasPermission('salary_tsalaryatta_add')")
	public R<Boolean> save(@RequestBody TSalaryAtta tSalaryAtta) {
		return R.ok(tSalaryAttaService.save(tSalaryAtta));
	}

	/**
	 * 修改薪资结算附件表
	 *
	 * @param tSalaryAtta 薪资结算附件表
	 * @return R
	 */
	@Operation(summary = "修改薪资结算附件表", description = "修改薪资结算附件表：hasPermission('salary_tsalaryatta_edit')")
	@SysLog("修改薪资结算附件表")
	@PutMapping
	@PreAuthorize("@pms.hasPermission('salary_tsalaryatta_edit')")
	public R<Boolean> updateById(@RequestBody TSalaryAtta tSalaryAtta) {
		return R.ok(tSalaryAttaService.updateById(tSalaryAtta));
	}

	/**
	 * 通过id删除薪资结算附件表
	 *
	 * @param id id
	 * @return R
	 */
	@Operation(summary = "通过id删除薪资结算附件表", description = "通过id删除薪资结算附件表：hasPermission('salary_tsalaryatta_del')")
	@SysLog("通过id删除薪资结算附件表")
	@DeleteMapping("/{id}")
	@PreAuthorize("@pms.hasPermission('salary_tsalaryatta_del')")
	public R<Boolean> removeById(@PathVariable String id) {
		return R.ok(tSalaryAttaService.removeById(id));
	}

}
