/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */

package com.yifu.cloud.plus.v1.yifu.salary.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yifu.cloud.plus.v1.yifu.common.core.util.R;
import com.yifu.cloud.plus.v1.yifu.common.log.annotation.SysLog;
import com.yifu.cloud.plus.v1.yifu.salary.entity.TSalaryStandardSet;
import com.yifu.cloud.plus.v1.yifu.salary.service.TSalaryStandardSetService;
import com.yifu.cloud.plus.v1.yifu.salary.vo.TSalaryStandardSetSearchVo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;


/**
 * 薪资工资条配置主表
 *
 * @author hgw
 * @date 2022-08-05 11:40:14
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/tsalarystandardset")
@Tag(name = "薪资工资条配置主表管理")
public class TSalaryStandardSetController {

	private final TSalaryStandardSetService tSalaryStandardSetService;


	/**
	 * 简单分页查询
	 *
	 * @param page               分页对象
	 * @param tSalaryStandardSet 薪资工资条配置主表
	 * @return
	 */
	@Operation(description = "简单分页查询")
	@GetMapping("/page")
	public R<IPage<TSalaryStandardSet>> getTSalaryStandardSetPage(Page<TSalaryStandardSet> page, TSalaryStandardSetSearchVo tSalaryStandardSet) {
		return new R<>(tSalaryStandardSetService.getTSalaryStandardSetPage(page, tSalaryStandardSet));
	}

	/**
	 * 不分页查询
	 *
	 * @param tSalaryStandardSet 薪资工资条配置主表
	 * @return
	 */
	@Operation(summary = "不分页查询", description = "不分页查询")
	@PostMapping("/noPage")
	//@PreAuthorize("@pms.hasPermission('salary_tsalarystandardset_get')" )
	public R<List<TSalaryStandardSet>> getTSalaryStandardSetNoPage(@RequestBody TSalaryStandardSetSearchVo tSalaryStandardSet) {
		return R.ok(tSalaryStandardSetService.noPageDiy(tSalaryStandardSet));
	}

	/**
	 * 通过id查询薪资工资条配置主表
	 *
	 * @param id id
	 * @return R
	 */
	@Operation(summary = "通过id查询", description = "通过id查询：hasPermission('salary_tsalarystandardset_get')")
	@GetMapping("/{id}")
	public R<TSalaryStandardSet> getById(@PathVariable("id") String id) {
		return R.ok(tSalaryStandardSetService.getById(id));
	}

	/**
	 * 新增薪资工资条配置主表
	 *
	 * @param tSalaryStandardSet 薪资工资条配置主表
	 * @return R
	 */
	@Operation(summary = "新增薪资工资条配置主表", description = "新增薪资工资条配置主表：hasPermission('salary_tsalarystandardset_add')")
	@SysLog("新增薪资工资条配置主表")
	@PostMapping
	@PreAuthorize("@pms.hasPermission('salary_tsalarystandardset_add')")
	public R<Boolean> save(@RequestBody TSalaryStandardSet tSalaryStandardSet) {
		return R.ok(tSalaryStandardSetService.save(tSalaryStandardSet));
	}

	/**
	 * 修改薪资工资条配置主表
	 *
	 * @param tSalaryStandardSet 薪资工资条配置主表
	 * @return R
	 */
	@Operation(summary = "修改薪资工资条配置主表", description = "修改薪资工资条配置主表：hasPermission('salary_tsalarystandardset_edit')")
	@SysLog("修改薪资工资条配置主表")
	@PutMapping
	@PreAuthorize("@pms.hasPermission('salary_tsalarystandardset_edit')")
	public R<Boolean> updateById(@RequestBody TSalaryStandardSet tSalaryStandardSet) {
		return R.ok(tSalaryStandardSetService.updateById(tSalaryStandardSet));
	}

	/**
	 * 通过id删除薪资工资条配置主表
	 *
	 * @param id id
	 * @return R
	 */
	@Operation(summary = "通过id删除薪资工资条配置主表", description = "通过id删除薪资工资条配置主表：hasPermission('salary_tsalarystandardset_del')")
	@SysLog("通过id删除薪资工资条配置主表")
	@DeleteMapping("/{id}")
	@PreAuthorize("@pms.hasPermission('salary_tsalarystandardset_del')")
	public R<Boolean> removeById(@PathVariable String id) {
		return R.ok(tSalaryStandardSetService.removeById(id));
	}

}
