/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */

package com.yifu.cloud.plus.v1.yifu.salary.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yifu.cloud.plus.v1.yifu.common.core.util.R;
import com.yifu.cloud.plus.v1.yifu.common.log.annotation.SysLog;
import com.yifu.cloud.plus.v1.yifu.salary.entity.TStatisticsTaxDeclarer;
import com.yifu.cloud.plus.v1.yifu.salary.service.TStatisticsTaxDeclarerService;
import com.yifu.cloud.plus.v1.yifu.salary.vo.TStatisticsTaxDeclarerSearchVo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;


/**
 * 统计-申报人员
 *
 * @author hgw
 * @date 2022-08-05 11:40:14
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/tstatisticstaxdeclarer")
@Tag(name = "统计-申报人员管理")
public class TStatisticsTaxDeclarerController {

	private final TStatisticsTaxDeclarerService tStatisticsTaxDeclarerService;


	/**
	 * 简单分页查询
	 *
	 * @param page                   分页对象
	 * @param tStatisticsTaxDeclarer 统计-申报人员
	 * @return
	 */
	@Operation(description = "简单分页查询")
	@GetMapping("/page")
	public R<IPage<TStatisticsTaxDeclarer>> getTStatisticsTaxDeclarerPage(Page<TStatisticsTaxDeclarer> page, TStatisticsTaxDeclarerSearchVo tStatisticsTaxDeclarer) {
		return new R<>(tStatisticsTaxDeclarerService.getTStatisticsTaxDeclarerPage(page, tStatisticsTaxDeclarer));
	}

	/**
	 * 通过id查询统计-申报人员
	 *
	 * @param id id
	 * @return R
	 */
	@Operation(summary = "通过id查询", description = "通过id查询：hasPermission('salary_tstatisticstaxdeclarer_get')")
	@GetMapping("/{id}")
	public R<TStatisticsTaxDeclarer> getById(@PathVariable("id") String id) {
		return R.ok(tStatisticsTaxDeclarerService.getById(id));
	}

	/**
	 * 通过id删除统计-申报人员
	 *
	 * @param id id
	 * @return R
	 */
	@Operation(summary = "通过id删除统计-申报人员", description = "通过id删除统计-申报人员：hasPermission('salary_tstatisticstaxdeclarer_del')")
	@SysLog("通过id删除统计-申报人员")
	@DeleteMapping("/{id}")
	@PreAuthorize("@pms.hasPermission('salary_tstatisticstaxdeclarer_del')")
	public R<Boolean> removeById(@PathVariable String id) {
		return R.ok(tStatisticsTaxDeclarerService.removeById(id));
	}

	/**
	 * 统计-申报人员 批量导出
	 *
	 * @author hgw
	 * @date 2022-08-05 11:40:14
	 **/
	@Operation(description = "导出统计-申报人员 hasPermission('salary_tstatisticstaxdeclarer-export')")
	@PostMapping("/export")
	@PreAuthorize("@pms.hasPermission('salary_tstatisticstaxdeclarer-export')")
	public void export(HttpServletResponse response, @RequestBody TStatisticsTaxDeclarerSearchVo searchVo) {
		tStatisticsTaxDeclarerService.listExport(response, searchVo);
	}
}
